Learn R Programming

wrMisc (version 2.0.0)

.complCols: Search (complementing) Columns For Best Coverage Of Non-NA Data For rowNormalization (main)

Description

This function was designed to complete the selection of columns of sparse matrix 'dat' with sets of 'nCombin' columns at complete 'coverage' Context : In sparse matrix 'dat' search subsets of columns with some rows as complete (no NA).

Usage

.complCols(x, dat, nCombin)

Value

This function returns a matrix of column-indexes complementing (nCombin rows)

Arguments

x

(integer, length=1) column number for with other columns to combine & give (some) complete non-NA lines are seeked

dat

(matrix) .. init data, smay be parse matrix with numerous NA

nCombin

(integer) .. number of columns used to make complete subset

See Also

rowNormalize; normalizeThis

Examples

Run this code
.complCols(3, dat=matrix(c(NA,12:17,NA,19),ncol=3), nCombin=3)

Run the code above in your browser using DataLab