Learn R Programming

wrMisc (version 2.0.0)

.rowNorm: Row-normalization Procedure On Matrix Or Data.frame (main)

Description

This function performs a row-normalization procedure on matrix or data.frame 'dat'

Usage

.rowNorm(
  dat,
  refLi,
  method,
  proportMode,
  maxFact = 10,
  fact0val = 10,
  retFact = FALSE,
  debug = FALSE,
  silent = FALSE,
  callFrom = NULL
)

Value

This function returns a matrix of normalized data same dimensions as 'dat'

Arguments

dat

(matrix) .. init data, smay be parse matrix with numerous NA

refLi

(NULL or numeric) allows to consider only specific lines of 'dat' when determining normalization factors (all data will be normalized)

method

(character) may be "mean","median" (plus "NULL","none"); When NULL or 'none' is chosen the input will be returned as is

proportMode

(logical) decide if normalization should be done by multiplicative or additive factor

maxFact

(numeric, length=2) max normalization factor

fact0val

(integer)

retFact

(logical)

debug

(logical) additional messages for debugging

silent

(logical) suppress messages

callFrom

(character) This function allows easier tracking of messages produced

See Also

rowNormalize; normalizeThis

Examples

Run this code
.rowNorm(matrix(11:31, ncol=3), refLi=1, method="mean", proportMode=TRUE)

Run the code above in your browser using DataLab