View source: R/countSameStartEnd.R
| countSameStartEnd | R Documentation |
Suppose a parent sequence/string 'ABCDE' gets cut in various fragments (eg 'ABC','AB' ...).
countSameStartEnd counts how many (ie re-occuring) start- and end- sites of edges do occur in the input-data.
The input is presented as matrix of/indicating start- and end-sites of edges.
The function is used to characterize partially redundant edges and accumulation of cutting/breakage sites.
countSameStartEnd(
frag,
minFreq = 2,
nDig = 4,
silent = FALSE,
debug = FALSE,
callFrom = NULL
)
frag |
(matrix) 1st column |
minFreq |
(integer) min number of accumulated sites for taking into account (allows filtering with large datasets) |
nDig |
(integer) rounding: number of digits for columns |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
callFrom |
(character) allows easier tracking of messages produced#' @return This function returns a matrix of 6 columns: input (beg and end), beg.n, beg.rat, end.n, end.rat |
to build initial tree buildTree, contribToContigPerFrag, simpleFragFig
frag1 <- cbind(beg=c(2,3,7,13,13,15,7,9,7, 3,3,5), end=c(6,12,8,18,20,20,19,12,12, 4,5,7))
rownames(frag1) <- letters[1:nrow(frag1)]
countSameStartEnd(frag1)
simpleFragFig(frag1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.