Learn R Programming

wrMisc (version 2.0.0)

cutToNgrp: Cut numeric vector to n groups (ie convert to factor)

Description

This function is a more elaborate version of cut for cutting a the content of a numeric vector 'x' into a given number of groups, taken from the length of 'lev'. Besides, this function provides the group borders/limits for convention use with legends.

Usage

cutToNgrp(
  x,
  lev,
  NAuse = FALSE,
  silent = FALSE,
  debug = FALSE,
  callFrom = NULL
)

Value

This function returns a list with $grouped telling which element of 'x' goes in which group and $legTxt with gourp-borders for convenient use with legends

Arguments

x

numeric vector

lev

(character or numeric), the length of this argument tells the number of groups to be used for cutting

NAuse

(logical) include NAs as separate group

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allows easier tracking of messages produced

See Also

Examples

Run this code
set.seed(2019); dat <- runif(30) +(1:30)/2
cutToNgrp(dat,1:5)
plot(dat,col=(1:5)[as.numeric(cutToNgrp(dat,1:5)$grouped)])

Run the code above in your browser using DataLab