extractLast2numericParts: Extract Last Two Numeric Parts From Character Vector

View source: R/extractLast2numericParts.R

extractLast2numericPartsR Documentation

Extract Last Two Numeric Parts From Character Vector

Description

This function extracts last 2 (integer) numeric parts between punctuations out of character vector 'x'. Runs faster than gregexpr . Note: won't work correctly with decimals or exponential signs !! (such characters will be considered as punctuation, ie as separator)

Usage

extractLast2numericParts(x, silent = FALSE, debug = FALSE, callFrom = NULL)

Arguments

x

main character input

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allow easier tracking of messages produced

Value

This function returns a (numeric) matrix with 2 columns (eg from initial concatenated coordinates)

See Also

gregexpr from grep

Examples

extractLast2numericParts(c("M01.1-4","M001/2.5","M_0001_03-16","zyx","012","a1.b2.3-7,2"))

wrMisc documentation built on March 9, 2026, 5:07 p.m.