triCoord: Pairwise x,y Combinations

View source: R/triCoord.R

triCoordR Documentation

Pairwise x,y Combinations

Description

This function gets pairwise combinations for 'n' elements; returns matrix with x & y coordinates to form all pairwise groups for 1:n elements

Usage

triCoord(n, side = "upper", silent = FALSE, debug = FALSE, callFrom = NULL)

Arguments

n

(integer) number of elements for making all pair-wise combinations

side

(character) "upper" or "lower"

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allow easier tracking of messages produced

Value

This function returns a 2-column matrix with indexes for all pairwise combinations of 1:n

See Also

upperMaCoord, getPWseparator, indexGroupsFromPW, diffCombin; combn, lower.tri or upper.tri, simpler version upperMaCoord

Examples

triCoord(4)

wrMisc documentation built on March 9, 2026, 5:07 p.m.