upperMaCoord: (upper) pairwise x,y combinations

View source: R/upperMaCoord.R

upperMaCoordR Documentation

(upper) pairwise x,y combinations

Description

upperMaCoord gets pairwise combinations for 'n' elements; return matrix with x & y coordinates to form all pairwise groups for n elements. But no distinction of 'upper' or 'lower' possible like in triCoord

Usage

upperMaCoord(n, silent = FALSE, debug = FALSE, callFrom = NULL)

Arguments

n

(integer) number of elements for making all pair-wise combinations

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allow easier tracking of messages produced

Value

This function returns a 2-column matrix wiyh indexes for all pairwise combinations of 1:n

See Also

lower.tri, more evolved version triCoord

Examples

upperMaCoord(4)

wrMisc documentation built on March 9, 2026, 5:07 p.m.