Learn R Programming

wrMisc (version 2.0.0)

withinRefRange: Check For Values Within Range Of Reference

Description

This function checks which values of numeric vector 'x' are within range +/- 'fa' x 'ref' (ie within range of reference).

Usage

withinRefRange(
  x,
  fa,
  ref = NULL,
  absRef = TRUE,
  asInd = FALSE,
  silent = FALSE,
  debug = FALSE,
  callFrom = NULL
)

Value

This function returns a numeric vector containing only the values within range of reference

Arguments

x

matrix or data.frame

fa

(numeric) absolute or relative tolerance value (numeric, length=1), interpreted according to 'absRef' as absolute or relative to 'x'(ie fa*ref)

ref

(numeric) (center) reference value for comparison (numeric, length=1), if not given mean of 'x' (excluding NA or non-finite values) will be used

absRef

(logical) return result as absolute or relative to 'x'(ie fa*ref)

asInd

(logical) if TRUE return index of which values of 'x' are within range, otherwise return values if 'x' within range

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allows easier tracking of messages produced

Examples

Run this code
## within 2.5 +/- 0.7
withinRefRange(-5:6,fa=0.7,ref=2.5)                
## within 2.5 +/- (0.7*2.5)
withinRefRange(-5:6,fa=0.7,ref=2.5,absRef=FALSE)

Run the code above in your browser using DataLab