contribToContigPerFrag: Characterize Individual Contribution Of Single Edges In Tree-Structures
Description
This function helps investigating tree-like structures with the aim of indicating how much individual tree components contribute
to compose long stretches.
This function returns a matrix of 3 columns for each node identified in rownames of joinMatr for length of longest tree-branches where given edge participates (column sumLen), the (total) number of edges therein (col n.frag) and a relative value (len.rat)
Arguments
joinMat
(matrix) matrix with concatenated edges as rownames (separated by slashes), column sumLen for total length and column n for number of edges
fullLength
(integer) custom total length (useful if the concatenated edges do not cover 100 percent of the original precursor whose fragments are studied)
nDig
(integer) rounding: number of digits for 3rd column len.rat in output
silent
(logical) suppress messages
callFrom
(character) allow easier tracking of messages produced
debug
(logical) additional messages for debugging
Details
contribToContigPerFrag characterizes individual (isolated) contribution of single edges in tree-structures.
Typically used to process/exploit summarized trees (as matrix) made by buildTree which makes use of the package data.tree.
For example if A,B and C can be joined aa well and B +D, this function will check if A+B+C is longer and if A contributes to the longest tree.