countSameStartEnd: Count Same Start- And End- Sites Of Edges (Or Fragments)
Description
Suppose a parent sequence/string 'ABCDE' gets cut in various fragments (eg 'ABC','AB' ...).
countSameStartEnd counts how many (ie re-occuring) start- and end- sites of edges do occur in the input-data.
The input is presented as matrix of/indicating start- and end-sites of edges.
The function is used to characterize partially redundant edges and accumulation of cutting/breakage sites.
(matrix) 1st column beg start-sites, 2nd column end end-sites of edges, rownames to precise fragment identities are recommended
minFreq
(integer) min number of accumulated sites for taking into account (allows filtering with large datasets)
nDig
(integer) rounding: number of digits for columns beg.rat and end.rat in output
silent
(logical) suppress messages
debug
(logical) additional messages for debugging
callFrom
(character) allows easier tracking of messages produced#' @return This function returns a matrix of 6 columns: input (beg and end), beg.n, beg.rat, end.n, end.rat
See Also
to build initial tree buildTree, contribToContigPerFrag, simpleFragFig