| diffCombin | R Documentation |
diffCombin returns matrix of differences (eg resulting from subsititution) for all pairwise combinations of numeric vector 'x'.
diffCombin(
x,
diagAsNA = FALSE,
prefix = TRUE,
silent = FALSE,
debug = FALSE,
callFrom = NULL
)
x |
numeric vector to compute differences for all combinations |
diagAsNA |
(logical) return all self-self combinations as NA (otherwise 0) |
prefix |
(logical) if TRUE, dimnames of output will specify orientation (prefix='from.' and 'to.') |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
callFrom |
(character) allows easier tracking of messages produced |
This function returns a numeric matrix of all pairwise differences
diff for simple differences
diffCombin(c(10,11.1,13.3,16.6))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.