Learn R Programming

wrMisc (version 2.0.0)

diffCombin: Compute Matrix Of Differences For All Pairwise Combinations Of Numeric Vector

Description

diffCombin returns matrix of differences (eg resulting from subsititution) for all pairwise combinations of numeric vector 'x'.

Usage

diffCombin(
  x,
  diagAsNA = FALSE,
  prefix = TRUE,
  silent = FALSE,
  debug = FALSE,
  callFrom = NULL
)

Value

This function returns a numeric matrix of all pairwise differences

Arguments

x

numeric vector to compute differences for all combinations

diagAsNA

(logical) return all self-self combinations as NA (otherwise 0)

prefix

(logical) if TRUE, dimnames of output will specify orientation (prefix='from.' and 'to.')

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allows easier tracking of messages produced

See Also

diff for simple differences

Examples

Run this code
diffCombin(c(10,11.1,13.3,16.6))

Run the code above in your browser using DataLab