extractLast2numericParts: Extract Last Two Numeric Parts From Character Vector
Description
This function extracts last 2 (integer) numeric parts between punctuations out of character vector 'x'.
Runs faster than gregexpr .
Note: won't work correctly with decimals or exponential signs !! (such characters will be considered as punctuation, ie as separator)