This function returns a matrix with boundaries of 1st and last usable column (NA if there were no suitable groups found)
Arguments
dat
(matrix or data.frame) main input
grp
(factor) information which column of 'dat' is replicate of whom
maxNA
(interger) max number of tolerated NAs
silent
(logical) suppress messages
debug
(logical) additional messages for debugging
callFrom
(character) allow easier tracking of messages produced
Details
To find groups within a specific range, this function searches independently each line of the input-matrix 'dat' for sretches with a given maximum of NA-instances ('maxNA').
This function is used to inspect/filter each lines of 'dat' for a subset with sufficient presence/absence of NA values (ie limit number of NAs per level of 'grp').
Note : optimal perfomance with n.lines >> n.groups