(NULL or matrix) adjust/ custom-modify search- and replacement items; default settings will exchange the beginning of the site to 'raw.githubusercontent.com' and then exchange 'blob' to 'refs/head'
otherwise should be matrix with 2 columns, the 1st colimn entries will be used as 'search-for' and the 2nd as 'replace by' for each row
silent
(logical) suppress messages
debug
(logical) additional messages for debugging
callFrom
(character) allow easier tracking of messages produced
Details
Thus, this will exchange the beginning of the site to 'raw.githubusercontent.com' and then exchange 'blob' to 'refs/head' .
Alternatively, the user may custom define all terms to get exchanged (as matrix with 2 columns 'old' and 'new').
Note : The default spearator from read.delim may suit better for reading the data.