This function provides collecions of typical separators used for combined names in pair-wise testing for later choice of the most suited.
pwSeparatorList(
type = "split1",
silent = FALSE,
debug = FALSE,
callFrom = NULL
)This function returns a charcter vector with proposed separators for later choosing the most suited
(character) allows selecting of different types of collections of separators
(logical) suppress messages
(logical) additional messages for debugging
(character) allow easier tracking of messages produced
Depending if one rather looks for separators for cutting existing names of for suggesting separators for fresh concatenation, two differentsets of collections are available via the argument type.
Using type="split" will default to type="split1", similarly type="combine" will be used as type="combine1".
The option type="split1" has a default collection of shorter/compact separators for splitting
The option type="split2" allows more extensive search for 38 separators (ie combinations with ' ','-' and '_'), but extensive checking may cost CPU time.
The option type="split3" has a shorter collection of 12 basic commonly used separators.
The option type="split4" to type="split9" default to 'split1'
The option type="combine1" does not suggest '--' (neither '__') since if '-' may not be chosen ins the first place, using '--' as separator next to '-' occuring inside gourp-names may not enhance visibility.
The option type="combine2" contains a collection of sperators using 'vs' or 'versus'
The option type="combine3" is designed for explicite terms (starts with ' - versus - ', for suggesting compact terms rather use type="combine1"
The option type="combine4" to type="combine9" default to 'combine1'
pwSeparatorList(type="split1")
Run the code above in your browser using DataLab