View source: R/indexGroupsFromPW.R
| replacePWseparator | R Documentation |
Replace Separator In Vector Of Pairwise Group-Names
This function allows identifying and substituting a separator used in a character vector concatenated of pairwise groups.
replacePWseparator(
compNames,
newSep,
potSep = c("-", "---", "_", "___", ".", "-vs-", "_vs_", "--vs--", "__vs__", " ", " "),
silent = FALSE,
debug = FALSE,
callFrom = NULL
)
compNames |
(character or integer) names of pairwise combined group-names |
newSep |
(character of length=1) new separator between group-names for pair of names; if |
potSep |
(character) potential separators to be checked if occuring in |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
callFrom |
(character) allow easier tracking of messages produced |
This function returns a character vector with group-wise substituted separators (or NULL if conflicts appear)
indexGroupsFromPW, getPWseparator, .getPWseparator
replacePWseparator(compNames=c("B-C","B-D","C-D"), newSep="-vs-")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.