View source: R/rmDupl2colMatr.R
| rmDupl2colMatr | R Documentation |
This function removes lines of matrix that are redundant /duplicated for 1st and 2nd column (irrespective of content of their columns). The first occurance of redundant /duplicated elements is kept.
rmDupl2colMatr(
mat,
useCol = c(1, 2),
silent = FALSE,
debug = FALSE,
callFrom = NULL
)
mat |
(matrix or data.frame) main input |
useCol |
(integer, length=2) columns to consider/use when looking for duplicated entries |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
callFrom |
(character) allow easier tracking of messages produced |
This function returns a matrix where duplictaed lines are removed
unlist
mat <- matrix(1:12,ncol=3)
mat[3,1:2] <- mat[1,1:2]
rmDupl2colMatr(mat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.