| rowGrpMeans | R Documentation |
Thus function calculates column-means for matrix with multiple groups of data, ie similar to rowMeans but one mean for each group of data. Groups are specified as columns of 'x' in 'grp' (so length of grp should match number of columns of 'x', NAs are allowed).
rowGrpMeans(
x,
grp,
na.rm = TRUE,
silent = FALSE,
debug = FALSE,
callFrom = NULL
)
x |
(numeric matrix or data.frame) main input |
grp |
(character or factor) defining which columns should be grouped (considered as replicates) |
na.rm |
(logical) a logical value indicating whether |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
callFrom |
(character) This function allows easier tracking of messages produced |
This function returns a matrix with mean values
rowSds, colSums which also shows colMeans
set.seed(2016); dat1 <- matrix(c(runif(200) +rep(1:10,20)), ncol=10)
head(rowGrpMeans(dat1, gr=gl(4, 3, labels=LETTERS[1:4])[2:11]))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.