rowGrpMeans: Row-Means With Destinction Of Groups (Of Columns, eg Groups Of Replicates)
Description
Thus function calculates column-means for matrix with multiple groups of data, ie similar to rowMeans but one mean for each group of data.
Groups are specified as columns of 'x' in 'grp' (so length of grp should match number of columns of 'x', NAs are allowed).