Learn R Programming

wrMisc (version 2.0.0)

triCoord: Pairwise x,y Combinations

Description

This function gets pairwise combinations for 'n' elements; returns matrix with x & y coordinates to form all pairwise groups for 1:n elements

Usage

triCoord(n, side = "upper", silent = FALSE, debug = FALSE, callFrom = NULL)

Value

This function returns a 2-column matrix with indexes for all pairwise combinations of 1:n

Arguments

n

(integer) number of elements for making all pair-wise combinations

side

(character) "upper" or "lower"

silent

(logical) suppress messages

debug

(logical) additional messages for debugging

callFrom

(character) allow easier tracking of messages produced

See Also

upperMaCoord, getPWseparator, indexGroupsFromPW, diffCombin; combn, lower.tri or upper.tri, simpler version upperMaCoord

Examples

Run this code
triCoord(4)

Run the code above in your browser using DataLab