powered by
This function gets pairwise combinations for 'n' elements; returns matrix with x & y coordinates to form all pairwise groups for 1:n elements
triCoord(n, side = "upper", silent = FALSE, debug = FALSE, callFrom = NULL)
This function returns a 2-column matrix with indexes for all pairwise combinations of 1:n
(integer) number of elements for making all pair-wise combinations
(character) "upper" or "lower"
(logical) suppress messages
(logical) additional messages for debugging
(character) allow easier tracking of messages produced
upperMaCoord, getPWseparator, indexGroupsFromPW, diffCombin; combn, lower.tri or upper.tri, simpler version upperMaCoord
upperMaCoord
getPWseparator
indexGroupsFromPW
diffCombin
combn
lower.tri
upper.tri
triCoord(4)
Run the code above in your browser using DataLab