| upperMaCoord | R Documentation |
upperMaCoord gets pairwise combinations for 'n' elements; return matrix with x & y coordinates to form all pairwise groups for n elements.
But no distinction of 'upper' or 'lower' possible like in triCoord
upperMaCoord(n, silent = FALSE, debug = FALSE, callFrom = NULL)
n |
(integer) number of elements for making all pair-wise combinations |
silent |
(logical) suppress messages |
debug |
(logical) additional messages for debugging |
callFrom |
(character) allow easier tracking of messages produced |
This function returns a 2-column matrix wiyh indexes for all pairwise combinations of 1:n
lower.tri, more evolved version triCoord
upperMaCoord(4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.