powered by
This function checks which values of numeric vector 'x' are within range +/- 'fa' x 'ref' (ie within range of reference).
withinRefRange( x, fa, ref = NULL, absRef = TRUE, asInd = FALSE, silent = FALSE, debug = FALSE, callFrom = NULL )
This function returns a numeric vector containing only the values within range of reference
matrix or data.frame
(numeric) absolute or relative tolerance value (numeric, length=1), interpreted according to 'absRef' as absolute or relative to 'x'(ie fa*ref)
(numeric) (center) reference value for comparison (numeric, length=1), if not given mean of 'x' (excluding NA or non-finite values) will be used
(logical) return result as absolute or relative to 'x'(ie fa*ref)
(logical) if TRUE return index of which values of 'x' are within range, otherwise return values if 'x' within range
(logical) suppress messages
(logical) additional messages for debugging
(character) allows easier tracking of messages produced
## within 2.5 +/- 0.7 withinRefRange(-5:6,fa=0.7,ref=2.5) ## within 2.5 +/- (0.7*2.5) withinRefRange(-5:6,fa=0.7,ref=2.5,absRef=FALSE)
Run the code above in your browser using DataLab